@@ -11,6 +11,11 @@ pub fn check() -> crate::Command {
     cargo("check")
 }
 
+#[must_use]
+pub fn fix() -> crate::Command {
+    cargo("fix")
+}
+
 #[must_use]
 pub fn test() -> crate::Command {
     cargo("test")
